#
# spec file for package perl-DBD-MariaDB
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name DBD-MariaDB
Name:           perl-DBD-MariaDB
Version:        1.21
Release:        lp155.5.1
Summary:        MariaDB and MySQL driver for the Perl5 Database Interface (DBI)
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/P/PA/PALI/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
# MANUAL BEGIN
Source2:        test-setup.sh
Source3:        test-clean.sh
BuildRequires:  libmariadb-devel
BuildRequires:  mariadb
BuildRequires:  zlib-devel
BuildRequires:  perl(B)
BuildRequires:  perl(CPAN::Meta::YAML)
BuildRequires:  perl(Config)
BuildRequires:  perl(Data::Dumper)
BuildRequires:  perl(Encode)
BuildRequires:  perl(ExtUtils::MakeMaker)
BuildRequires:  perl(File::Spec)
BuildRequires:  perl(File::Temp)
BuildRequires:  perl(FindBin)
BuildRequires:  perl(Getopt::Long)
BuildRequires:  perl(Net::SSLeay)
BuildRequires:  perl(Proc::ProcessTable)
BuildRequires:  perl(Storable)
BuildRequires:  perl(TAP::Harness)
BuildRequires:  perl(Test::Pod) >= 1.41
BuildRequires:  perl(Time::HiRes)
BuildRequires:  perl(bigint)
BuildRequires:  perl(lib)
BuildRequires:  perl(strict)
BuildRequires:  perl(utf8)
BuildRequires:  perl(vars)
BuildRequires:  perl(warnings)
Requires:       perl(DynaLoader)
Requires:       perl(strict)
Requires:       perl(warnings)
# MANUAL END
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(DBI) >= 1.608
BuildRequires:  perl(DBI::Const::GetInfoType)
BuildRequires:  perl(Devel::CheckLib) >= 1.11
BuildRequires:  perl(Test::Deep)
BuildRequires:  perl(Test::More) >= 0.90
Requires:       perl(DBI) >= 1.608
%{perl_requires}

%description
*DBD::MariaDB* is the Perl5 Database Interface driver for MariaDB and MySQL
databases. In other words: DBD::MariaDB is an interface between the Perl
programming language and the MariaDB/MySQL programming API that comes with
the MariaDB/MySQL relational database management system. Most functions
provided by this programming API are supported. Some rarely used functions
are missing, mainly because no-one ever requested them.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}


%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%license LICENSE
%doc Changes Changes.historic

%changelog
* Mon Jul  8 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Enabled tests during build
  * Added files test-setup.sh and test-clean.sh
  * Added test dependecies: Proc::ProcessTable and mariadb
* Mon Jun  3 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Reduce the description and delete useless defattr
* Mon Jun  3 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Tests can't be run inside the buildroot, test manually before submit
* Wed Feb 27 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- update to 1.21 2019-02-27
  * 1.21 2019-02-27
  - Fix skipping test t/14destruct.t
  - Revert "MySQL bug #93276 is fixed in 8.0.15"
    (https://github.com/gooddata/DBD-MariaDB/issues/137)
* Tue Feb 26 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- update to 1.20 2019-02-22
  * 1.20 2019-02-22
  - Fix compilation on Windows
  - Fix tests for MariaDB 10.2.20+, 10.3.12+ and 10.4.1+
  - Fix processing of unfetched multi result sets
  - Cover a protocol design error for multi result statements
  - Fix $dbh->last_insert_id for async calls and multi result statements
  - Add more robust solution to prevent deinitializing OpenSSL functions
    (https://github.com/gooddata/DBD-MariaDB/issues/119)
  - Set $sth->{Active} to off after fetching all data
    (https://github.com/jhthorsen/mojo-mysql/pull/47#issuecomment-448095164)
  - Fix $sth->rows for async, multi results and when error occurred
  - Fix disconnect_all() method to work also during global destruction phase
  - Address MySQL bug #93276 which is fixed in 8.0.15
* Tue Feb 19 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Cleaned with spec-cleaner
* Tue Feb 19 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- initial package 1.11
  * 1.11 2019-01-02
  - Fix breakage of Net::SSLeay / OpenSSL library after DBI disconnect
    (https://github.com/gooddata/DBD-MariaDB/issues/119)
  * 1.10 2018-12-05
  - Fix spelling error (https://github.com/gooddata/DBD-MariaDB/issues/82)
  - Fix MinGW build (https://github.com/gooddata/DBD-MariaDB/issues/91)
  - Fix DBI SQL types (https://github.com/gooddata/DBD-MariaDB/issues/109)
  - Fix overflow in mariadb_thread_id and mariadb_warning_count attributes
  - Fix parsing LIMIT keyword (case-insensitive + allow whitespaces around)
  - Fix allocating and releasing memory when using Embedded Server
  - Fix escaping placeholders when sql_mode is NO_BACKSLASH_ESCAPES
  - Fix output from Unicode related tests
  - Fix setting client_flag for mysql_real_connect()
  - Fix calling DBI->data_sources() without second argument
  - Fix $dbh->last_insert_id() for multi and prepared server side statements
  - Use dbd_db_do6 API from DBI 1.642 when available
  - Add support for a new DBI method call $sth->last_insert_id()
  - Add sanity check for Makefile.PL --testsocket, --testhost and --testport
  - Report error when $dbh->{mariadb_ssl_cipher} attribute is not supported
  - Check that correct number of bind parameters are in $dbh->do()
  - Update workarounds for bugs in MariaDB client library (some were fixed)
  - Allow to set zero read, write and connect timeout (which means infinite)
  - Set default session collation to utf8mb4_unicode_ci for real Unicode
  - Change minimal MySQL client version to 4.1.8 (older is incompatible)
  - Skip tests which cannot be started on current system/architecture
  - Move testrules.yml to t/ directory
  - Miscellaneous fixes in tests
  * 1.00 2018-07-12
  - Do not remove test name and line from test error messages
  - Update documentation for mariadb_length and mariadb_max_length
  - Fix retrieving ODBC attribute SQL_USER_NAME via $dbh->get_info()
  - Do not show internal DBI packages on cpan
  - Fix checking for error value from mariadb_embedded options
  - Makefile.PL shows error message when no client library was specified
  - Fix checking if integer value should be signed or unsigned
  * 0.90_01 2018-06-26 (beta)
  - This is a new DBD::MariaDB driver, fork of DBD::mysql 4.041 with fixes
  - Attributes and methods with mysql_* prefix were renamed to mariadb_*
  - See https://metacpan.org/source/PALI/DBD-MariaDB-0.90_01/Changes
